@@ -10,13 +10,14 @@ using namespace Qt::Literals::StringLiterals;
 #include "gravatarsettings.h"
 #include <Gravatar/GravatarCache>
 #include <KConfigDialogManager>
+#include <KLocalization>
 #include <KLocalizedString>
-#include <KPluralHandlingSpinBox>
 #include <KSeparator>
 #include <QCheckBox>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QPushButton>
+#include <QSpinBox>
 #include <QVBoxLayout>
 
 using namespace Gravatar;
@@ -27,15 +28,15 @@ GravatarConfigureSettingsWidget::GravatarConfigureSettingsWidget(QWidget *parent
     auto topLayout = new QVBoxLayout(this);
     topLayout->setObjectName("mainlayout"_L1);
     topLayout->setContentsMargins(0, 0, 0, 0);
-    mUseDefaultPixmap = new QCheckBox(i18n("Use Default Image"), this);
+    mUseDefaultPixmap = new QCheckBox(i18nc("@option:check", "Use Default Image"), this);
     mUseDefaultPixmap->setObjectName("kcfg_GravatarUseDefaultImage"_L1);
     topLayout->addWidget(mUseDefaultPixmap);
 
-    mUseLibravatar = new QCheckBox(i18n("Use Libravatar"), this);
+    mUseLibravatar = new QCheckBox(i18nc("@option:check", "Use Libravatar"), this);
     mUseLibravatar->setObjectName("kcfg_LibravatarSupportEnabled"_L1);
     topLayout->addWidget(mUseLibravatar);
 
-    mFallbackGravatar = new QCheckBox(i18n("Fallback to Gravatar"), this);
+    mFallbackGravatar = new QCheckBox(i18nc("@option:check", "Fallback to Gravatar"), this);
     mFallbackGravatar->setObjectName("kcfg_FallbackToGravatar"_L1);
     topLayout->addWidget(mFallbackGravatar);
     connect(mUseLibravatar, &QCheckBox::toggled, mFallbackGravatar, &QCheckBox::setEnabled);
@@ -47,10 +48,10 @@ GravatarConfigureSettingsWidget::GravatarConfigureSettingsWidget(QWidget *parent
     lab->setObjectName("gravatarcachesizelabel"_L1);
     cacheSizeLayout->addWidget(lab);
 
-    mGravatarCacheSize = new KPluralHandlingSpinBox(this);
+    mGravatarCacheSize = new QSpinBox(this);
     mGravatarCacheSize->setMinimum(1);
     mGravatarCacheSize->setMaximum(9999);
-    mGravatarCacheSize->setSuffix(ki18ncp("add space before image", " image", " images"));
+    KLocalization::setupSpinBoxFormatString(mGravatarCacheSize, ki18ncp("add space before image", "%v image", "%v images"));
     mGravatarCacheSize->setObjectName("kcfg_GravatarCacheSize"_L1);
     cacheSizeLayout->addWidget(mGravatarCacheSize);
     cacheSizeLayout->addStretch();
